@@ -2,11 +2,12 @@ from shexer.model.statement import Statement
 
 class FixedPropChoiceStatement(Statement):
 
-    def __init__(self, st_property, st_types, cardinality, probability, comments=None,
+    def __init__(self, st_property, st_types, cardinality, n_occurences, probability, comments=None,
                  serializer_object=None, is_inverse=False):
         super(FixedPropChoiceStatement, self).__init__(st_property=st_property,
                                                        st_type=None,
                                                        cardinality=cardinality,
+                                                       n_occurences=n_occurences,
                                                        probability=probability,
                                                        comments=comments,
                                                        serializer_object=serializer_object,
